pub struct EvictionList {
unique_entries: HashMap<Hash, Instant>,
ordered_entries: VecDeque<Hash>,
max_size: usize,
eviction_memory_time: Duration,
}Expand description
An eviction list that allows Zebra to efficiently add entries, get entries, and remove older entries in the order they were inserted.
Fields
unique_entries: HashMap<Hash, Instant>ordered_entries: VecDeque<Hash>max_size: usizeeviction_memory_time: DurationThe mempool transaction eviction age limit.
Same as Config::eviction_memory_time.
Implementations
Sourceimpl EvictionList
impl EvictionList
Sourcepub fn new(max_size: usize, eviction_memory_time: Duration) -> Self
pub fn new(max_size: usize, eviction_memory_time: Duration) -> Self
Create a new EvictionList with the given maximum size and
eviction time.
Sourcepub fn insert(&mut self, key: Hash)
pub fn insert(&mut self, key: Hash)
Inserts a TXID in the list, keeping track of the time it was inserted.
All entries older than EvictionList::eviction_memory_time will be removed.
Panics
If the TXID is already in the list.
Sourcepub fn contains_key(&self, txid: &Hash) -> bool
pub fn contains_key(&self, txid: &Hash) -> bool
Checks if the given TXID is in the list.
Sourcefn pop_front(&mut self) -> Option<Hash>
fn pop_front(&mut self) -> Option<Hash>
Removes the first element and returns it, or None if the EvictionList
is empty.
Sourcefn has_expired(&self, evicted_at: &Instant) -> bool
fn has_expired(&self, evicted_at: &Instant) -> bool
Returns if evicted_at is considered expired considering the current
time and the configured eviction time.